#! /usr/bin/env bash

alias @=abcli

alias @T=abcli_terraform
alias @terraform=abcli_terraform

alias @act=abcli_perform_action
alias @action=abcli_perform_action
alias @perform_action=abcli_perform_action

alias @build_README=abcli_build_README

alias @conda=abcli_conda

alias @create_video=abcli_create_video

alias @ffmpeg=abcli_ffmpeg

alias @git=abcli_git
alias @git++="abcli_git increment_version"

alias @gpu=abcli_gpu

alias @init=abcli_init

alias @instance=abcli_instance

alias @latex=abcli_latex

alias @mac='if [ "$abcli_is_mac" == true ]; then'
alias @.='fi'

alias @pip=abcli_pip

alias @plugins=abcli_plugins

alias @pypi=abcli_pypi

alias @random=abcli_string_random

alias @seed=abcli_seed

alias @sleep=abcli_sleep

alias @ssm=abcli_ssm

alias @storage=abcli_storage

alias @version="abcli version"

alias @watch=abcli_watch

alias @wifi=abcli_wifi
